.. highlight:: shell

============
Installation
============

Requirements
------------

`sxm` requires Python 3.6+. It will not work on older version or Python
2 at all.

Github
------

`sxm` is not avaible on PyPi quite yet, as a result, you currently have to
install it from Github directory. You can do this by running:

.. code-block:: console

    $ pip install https://github.com/AngellusMortis/sxm-client/tarball/master#egg=sxm-0.1.0

From sources
------------

The sources for sxm-client can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/AngellusMortis/sxm-client

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/AngellusMortis/sxm-client/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/AngellusMortis/sxm-client
.. _tarball: https://github.com/AngellusMortis/sxm-client/tarball/master
